Enum BrakeMode Copy item path Source pub enum BrakeMode {
Coast,
Brake,
Hold,
}Expand description The brake mode determines how motors behave when stopped.
Each mode offers different trade-offs between stopping speed, position accuracy,
and power consumption:
Coast : Lowest power consumption, but least precise stopping
Brake : Good balance between speed and precision
Hold : Most precise, but highest power consumption
 Examples
use ev3_drivebase::BrakeMode;
let casual = BrakeMode::Coast;
let controlled = BrakeMode::Brake;
let precise = BrakeMode::Hold;The motor will freely coast to a stop.
No active braking is applied. The motor will gradually slow down due to friction.
This mode uses the least power but provides the least control over stopping position.
The motor will actively brake, resisting motion until it comes to a stop.
Slows the motor faster than Coast but does not hold the final position.
After stopping, the motor can be moved freely by external forces.
The motor will actively hold its current position once stopped.
Provides the most precise stopping and maintains position against external forces.
This mode consumes more power as it continuously applies holding torque.
Converts this type into a shared reference of the (usually inferred) input type.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Converts to this type from the input type.
Converts to this type from the input type.
Compares and returns the maximum of two values.
Read more Compares and returns the minimum of two values.
Read more Restrict a value to a certain interval.
Read more Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
This method returns an ordering between
self and
other values if one exists.
Read more Tests less than (for
self and
other) and is used by the
< operator.
Read more Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more Tests greater than (for
self and
other) and is used by the
>
operator.
Read more Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.