DriveBase

Struct DriveBase 

pub struct DriveBase {
    pub left: TachoMotor,
    pub right: TachoMotor,
    pub current_speed: i32,
    pub left_sensor: Option<ColorSensor>,
    pub right_sensor: Option<ColorSensor>,
    pub left_meta: Motor,
    pub right_meta: Motor,
    pub circumference: f64,
    pub axle_track: f64,
}
The DriveBase struct which holds all the needed fields

Fields

left: TachoMotor

The left motor of the DriveBase

right: TachoMotor

The right motor of the DriveBase

current_speed: i32

Current speed of the robot

left_sensor: Option<ColorSensor>

left color sensor if specified, useful for line following methods

right_sensor: Option<ColorSensor>

right color sensor if specified, useful for line following methods

left_meta: Motor

Metadata of the left motor

right_meta: Motor

Metadata of the right motor

circumference: f64

The circumference of the wheels in mm

axle_track: f64

The distance between the points where both wheels touch the ground.

Implementations

Source

impl DriveBase

pub fn set_brake_mode(&self, brake_mode: BrakeMode) -> Result<&Self, Ev3Error>

Sets the brake mode of both motors. Its either Coast, Brake or Hold.

Errors

Errors if it can’t set the command

pub fn get_brake_mode(&self) -> Result<BrakeMode, Ev3Error>

Gets the brake mode for both motors. If the motors have different brake modes, this sets the right motor’s brake mode to match the left motor’s.

Errors

Errors if it can’t read the brake mode

Source

impl DriveBase

pub fn drive( &mut self, speed: i32, distance: impl Into<i32>, stop: bool, ) -> Result<&Self, Ev3Error>

Drives the robot forward or backward at the specified speed.

Parameters
  • speed: The speed at which to drive the robot, in tacho counts per second (positive for forward, negative for backward).
  • distance: Optional distance to drive, in millimeters.
    • If Some(mm), the robot drives that distance and then stops.
    • If None, the robot will drive indefinitely until another command stops it.
Errors

Returns an Ev3Error if the motor cannot be started or a command fails.

Example

Drive forward 500 mm at speed 200:

robot.drive(200, 500)?;
Source

impl DriveBase

pub fn set_acceleration(&self, acceleration: i32) -> Result<&Self, Ev3Error>

Sets the acceleration of the drivebase in deg/s^2

Errors

Errors if the value is negative or it can’t set the value

pub fn set_deceleration(&self, deceleration: i32) -> Result<&Self, Ev3Error>

Sets the deceleration of the drivebase in deg/s^2

Errors

Errors if the value is negative or it can’t set the value

Source

impl DriveBase

pub fn turn( &mut self, speed: i32, degree: i32, radius: impl Into<Option<f64>>, ) -> Result<&mut Self, Ev3Error>

Source

impl DriveBase

pub fn stop(&self) -> Result<&Self, Ev3Error>

Stops both motors and is called on drop.

Errors

Errors if it can’t set the stop command.

pub fn reset(&self) -> Result<&Self, Ev3Error>

Resets all of the parameters of both motors and the DriveBase. Has the added effect of stopping.

Errors

Errors if it can’t reset the DriveBase.

pub fn is_running(&self) -> Result<bool, Ev3Error>

If power is being sent to both motors.

Errors

Errors if it can’t set the stop command.

pub fn is_ramping(&self) -> Result<bool, Ev3Error>

If any one of the motors are still ramping up.

Errors

Errors if it can’t read the sysfs

pub fn is_holding(&self) -> Result<bool, Ev3Error>

If any one of the motors are holding.

Errors

Errors if it can’t read the sysfs

pub fn is_overloaded(&self) -> Result<bool, Ev3Error>

If any one of the motors are overloaded.

Errors

Errors if it can’t read the sysfs

pub fn is_stalled(&self) -> Result<bool, Ev3Error>

If any one of the motors are stalled.

Errors

Errors if it can’t read the sysfs

Source

impl DriveBase

pub fn wait<F>(&self, cond: F, timeout: Option<Duration>)
where F: Fn(&TachoMotor, &TachoMotor) -> bool + Send + Sync,

Wait until condition cond returns true or the timeout is reached.

The condition is checked when to the state attribute has changed. If the timeout is None it will wait an infinite amount of time.

Source

impl DriveBase

pub fn new( left_meta: Motor, right_meta: Motor, wheel_diameter: f64, axle_track: f64, ) -> Result<Self, Ev3Error>

Creates a new DriveBase using the provided Motor structs for the left and right motor.

Errors

Errors if the port is not used or used by another device.

pub fn add_colorsensor( &mut self, left_sensor: ColorSensor, right_sensor: ColorSensor, ) -> &Self

Add left and right colorsensors